function [] = mx_build_initial_data(float_data)

% mx_build_initial_data                         Build the initial data file
%==========================================================================
%
% USAGE:
%  [] = mx_build_initial_data(float_data)
%
% DESCRIPTION:
%  Builds a data set for the initial analysis using the provided float data
%  and saved this data set as a structure 'initial_data.mat'
%
% INPUT:
%   float_data  = name of .mat file to be analysed e.g. 'float_data_v2'
%   run         = index of run e.g. 'a'
%
% OUTPUT:
%  initial_data.mat                      
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (16th June, 2014)
%
%==========================================================================
display('Building initial data file...');

% Load the data
load(float_data);

%% Identify the float ID
% List all variables:
variables=who;
% Looks for variables with a float name e.g. 'F3760'
for i=1:length(variables)
    nb_charac=cell2mat(cellfun(@size,variables(i),'uni',false));
    if nb_charac(2) == 5 % identifies variables with 5 characters
        f_charac=strfind(cellstr(variables(i)),'F');
        % looks for variables starting with the letter 'F'
        if cell2mat(f_charac)==1
            % Identifies the float ID
            float=strtok(cellstr(variables(i)),'F');
            % float ID
            flt=str2num(cell2mat(float));
        end
    end
end

%% FIELDS TO RENAME
eval(['[F' int2str(flt) '.Pctd]=F' int2str(flt) '.Pctd_cal;']);
eval(['[F' int2str(flt) '.S]=F' int2str(flt) '.S_cal;']);
eval(['[F' int2str(flt) '.T]=F' int2str(flt) '.T_cal;']);
eval(['[F' int2str(flt) '.Pef]=F' int2str(flt) '.Pef_cal;']);
eval(['[F' int2str(flt) '.U1]=F' int2str(flt) '.U1_abs;']);
eval(['[F' int2str(flt) '.U2]=F' int2str(flt) '.U2_abs;']);
eval(['[F' int2str(flt) '.V1]=F' int2str(flt) '.V1_abs;']);
eval(['[F' int2str(flt) '.V2]=F' int2str(flt) '.V2_abs;']);
    
%% FIELDS TO REMOVE
% Remove the below list of fields:
fields={'S_cal' 'T_cal' 'Pctd_cal' 'Pef_cal' 'U1_abs' 'U2_abs' 'V1_abs' 'V2_abs'};
eval(['Flt' int2str(flt) '=rmfield(F' int2str(flt) ',fields);']);

%% SAVE STRUCTURE
save('initial_data.mat','-regexp','^Flt','^flt');