
if isempty(which('lastgood2.m'))
    fprintf(2,'You need to add the MX "private1" subdirectory to your path. \n');
end

if isempty(which('lastgood2.m'))
    error('You have not added the MX subdirectories to you MATLAB Path')
end

float_data='float_data_vmx';
run='test';
fig='off';
dummy = which('lastgood2.m');
directory = [dummy(1:end-20)];
mx_parameters='mx_parameters';

fprintf(1,' \n');
fprintf(1,'This function is running 36 stored vertical profiles of temperature, \n');
fprintf(1,'salinity and horizontal velocity from the EM-APEX float 3951 through\n');
fprintf(1,'all the functions in the MX Oceanographic Toolbox.\n');
fprintf(1,' \n');

mx_cf.mx_chks = 1;


%% Check value of constants and parameters in mx_parameters.mat
load(mx_parameters);

fprintf(1,' \n');
fprintf(1,'Check value of constants and parameters \n');
fprintf(1,'in the parameter file mx_parameters.mat \n');
fprintf(1,' \n');

U = parameters.U;
if eval(['' U '-1']) > 1e-13
    fprintf(2,'Parameter U:   Failed\n');
    mx_cf.mx_chks = 0;
end

V = parameters.V;
if eval(['' V '-1']) > 1e-13
    fprintf(2,'Parameter V:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.moving_window - 20) > 1e-13
    fprintf(2,'Parameter moving_window:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.dzN2ref - 24) > 1e-13
    fprintf(2,'Parameter dzN2ref:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.dzN2 - 6) > 1e-13 
    fprintf(2,'Parameter dzN2:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.drho - 0.03) > 1e-13 
    fprintf(2,'Parameter drho:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.dz - 3) > 1e-13 
    fprintf(2,'Parameter dz:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.dzs - 6) > 1e-13 
    fprintf(2,'Parameter dzs:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.fftpt - 128) > 1e-13 
    fprintf(2,'Parameter fftpt:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.lzmin_fixed - 50) > 1e-13 
    fprintf(2,'Parameter lzmin_fixed:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.lzmax_fixed - 300) > 1e-13 
    fprintf(2,'Parameter lzmax_fixed:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.R - 5) > 1e-13 
    fprintf(2,'Parameter R:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.gamma - 0.2) > 1e-13 
    fprintf(2,'Parameter gamma:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.epsilon0 - 8e-10) > 1e-13 
    fprintf(2,'Parameter epsilon0:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.N0 - 0.0052) > 1e-4 
    fprintf(2,'Parameter N0:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.f0 - 7.8360e-5) > 1e-8 
    fprintf(2,'Parameter f0:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.E - 6.3e-5) ~= 0 
    fprintf(2,'Parameter E:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.b - 1300) > 1e-13 
    fprintf(2,'Parameter b:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.jstar - 3) > 1e-13
    fprintf(2,'Parameter jstar:   Failed\n');
    mx_cf.mx_chks = 0;
end

spectralmethod = parameters.spectral_method;
string='Tycho2';
if eval(' spectralmethod ') ~= eval(' string ')
    fprintf(2,'Parameter spectral_method:   Failed\n');
    mx_cf.mx_chks = 0;
end

cospectralmethod = parameters.cospectral_method;
string='Tycho2_cospectra';
if eval(' cospectralmethod ') ~= eval(' string ')
    fprintf(2,'Parameter cospectral_method:   Failed\n');
    mx_cf.mx_chks = 0;
end

if abs(parameters.switch_fd - 1) > 1e-13 
    fprintf(2,'Parameter switch_fd:   Failed\n');
    mx_cf.mx_chks = 0;
end

if isnan(parameters.crit_rat) ~= 1 
    fprintf(2,'Parameter crit_rat:   Failed\n');
    mx_cf.mx_chks = 0;
end

if isnan(parameters.lzmin_threshold) ~= 1 
    fprintf(2,'Parameter lzmin_threshold:   Failed\n');
    mx_cf.mx_chks = 0;
end

clear E N0 R U V b cospectralmethod critrat drho dz dzN2ref dzN2 dzs epsilon0 f0 fftpt gamma jstar lzmaxfixed lzminfixed lzminthreshold movingwindow spectralmethod string switchfd

%% Load and build datasets
if exist('parameters','var')==0;
    fprintf(2,'load parameters:   Failed\n');
    mx_cf.mx_chks = 0;
end

mx_build_initial_data(float_data)
if exist('initial_data.mat','file')==0;
    fprintf(2,'mx_build_initial_data:   Failed\n');
    mx_cf.mx_chks = 0;
end

%% Derive fallrate of the EM-APEX floats
mx_derive_fallrate
load initial_data.mat
if isempty(['Flt' int2str(flt) '(1).fallrate)']);
    fprintf(2,'mx_derive_fallrate:   Failed\n');
    mx_cf.mx_chks = 0;
end
clear(['Flt' int2str(flt) ''])
clear flt

%% Grid CTD data onto 2.2dbar and EM on 3dbar
mx_grid_initialdata(parameters.U,parameters.V)

%% Derive initial variables
mx_derive_abs_T_S
mx_derive_potential_density_anomaly
mx_derive_N2(parameters.dzN2)
mx_derive_mixed_layer_depth(parameters.drho)
mx_derive_current_speed

load initial_data.mat

if isempty(['float' int2str(flt) '(1).SA)'])==1;
    fprintf(2,'mx_derive_abs_T_S:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(['float' int2str(flt) '(1).CT)'])==1;
    fprintf(2,'mx_derive_abs_T_S:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(['float' int2str(flt) '(1).sigma_0)'])==1;
    fprintf(2,'mx_derive_potential_density_anomaly:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(['float' int2str(flt) '(1).N2)'])==1;
    fprintf(2,'mx_derive_N2:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(['float' int2str(flt) '(1).MLD)'])==1;
    fprintf(2,'mx_derive_mixed_layer_depth:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(['float' int2str(flt) '(1).speed)'])==1;
    fprintf(2,'mx_derive_current_speed:   Failed\n');
    mx_cf.mx_chks = 0;
end

clear(['float' int2str(flt) ''])
clear flt

%% Plot main variables
fprintf(1,' \n');
fprintf(1,'The default set up for the MX analysis is that output \n');
fprintf(1,'figures are turned off (do not appear on the screen)\n');
fprintf(1,'and are saved instead in the ''figures'' folder.\n');
fprintf(1,' \n');

mx_grid_all_initial_data
if exist('initial_data_gridded.mat','file')==0;
    fprintf(2,'mx_grid_all_initial_data:   Failed\n');
    mx_cf.mx_chks = 0;
end

mx_plot_temperature(fig,directory)
mx_plot_salinity(fig,directory)
mx_plot_N2(fig,directory)
mx_plot_mixed_layer_depth(fig,directory)
mx_plot_current_speed(fig,directory)
if exist([directory,'figures',directory(end),'temperature.eps'],'file')==0; 
    fprintf(2,'mx_plot_temperature:   Failed\n');
    mx_cf.mx_chks = 0;
end
if exist([directory,'figures',directory(end),'salinity.eps'],'file')==0;
    fprintf(2,'mx_plot_salinity:   Failed\n');
    mx_cf.mx_chks = 0;
end
if exist([directory,'figures',directory(end),'N2.eps'],'file')==0;
    fprintf(2,'mx_plot_N2:   Failed\n');
    mx_cf.mx_chks = 0;
end
if exist([directory,'figures',directory(end),'mixed_layer_depth.eps'],'file')==0;
    fprintf(2,'mx_plot_mixed_layer_depth:   Failed\n');
    mx_cf.mx_chks = 0;
end
if exist([directory,'figures',directory(end),'current_speed.eps'],'file')==0;
    fprintf(2,'mx_plot_current_speed:   Failed\n');
    mx_cf.mx_chks = 0;
end

%% Derive mixing variables
mx_derive_N2_ref(parameters.moving_window,parameters.dzN2ref)
mx_derive_N2_100m
mx_derive_strain
mx_derive_shear(parameters.dz,parameters.dzs)

load mixing_data.mat

if isempty(mixing_data(1).N2_ref)==1;
    fprintf(2,'mx_derive_N2_ref:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(mixing_data(1).N2_100m)==1;
    fprintf(2,'mx_derive_N2_100m:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(mixing_data(1).strain)==1;
    fprintf(2,'mx_derive_strain:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(mixing_data(1).shear)==1;
    fprintf(2,'mx_derive_shear:   Failed\n');
    mx_cf.mx_chks = 0;
end

clear mixing_data flt

%% Derive mixing
mx_grid_mixingdata(parameters.dz)
if exist('mixing_data_gridded.mat','file')==0;
    fprintf(2,'mx_grid_mixingdata:   Failed\n');
    mx_cf.mx_chks = 0;
end

mixing_data_gridded=mx_derive_mixing(parameters.dz,parameters.fftpt,parameters.lzmin_fixed,parameters.lzmax_fixed,mx_parameters,run);

load(['mixing_data_gridded_' run '.mat'])
if isempty(mixing_data_gridded.epsilon)==1;
    fprintf(2,'mx_derive_mixing:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(mixing_data_gridded.Kz)==1;
    fprintf(2,'mx_derive_mixing:   Failed\n');
    mx_cf.mx_chks = 0;
end
if isempty(mixing_data_gridded.Rw)==1;
    fprintf(2,'mx_derive_mixing:   Failed\n');
    mx_cf.mx_chks = 0;
end
clear mixing_data_gridded flt

if exist(['mixing_data_gridded_' run '.mat'],'file')==0;
    fprintf(2,'mx_derive_mixing:   Failed\n');
    mx_cf.mx_chks = 0;
end

%% Plot main mixing variables
fprintf(1,' \n');
fprintf(1,'The default set up for the MX analysis is that output \n');
fprintf(1,'figures are turned off (do not appear on the screen)\n');
fprintf(1,'and are saved instead in the ''figures'' folder.\n');
fprintf(1,' \n');

mx_plot_dissipation_rate(fig,directory,run)
mx_plot_diffusivity(fig,directory,run)
mx_plot_CCW_CW(fig,directory,run)
mx_plot_Rw(fig,directory,run)

if exist([directory,'figures',directory(end),'dissipation_rate.eps'],'file')==0;
    fprintf(2,'mx_plot_dissipation_rate:   Failed\n');
    mx_cf.mx_chks = 0;
end
if exist([directory,'figures',directory(end),'diffusivity.eps'],'file')==0;
    fprintf(2,'mx_plot_diffusivity:   Failed\n');
    mx_cf.mx_chks = 0;
end
if exist([directory,'figures',directory(end),'CCW_CW.eps'],'file')==0;
    fprintf(2,'mx_plot_CCW_CW:   Failed\n');
    mx_cf.mx_chks = 0;
end
if exist([directory,'figures',directory(end),'Rw.eps'],'file')==0;
    fprintf(2,'mx_plot_Rw:   Failed\n');
    mx_cf.mx_chks = 0;
end

%% Diagnostic results
if mx_cf.mx_chks == 1 ;
    fprintf(1,' Finished.\n');
    fprintf(1,'\n');
end

if mx_cf.mx_chks == 0
    fprintf(2,'Your installation of the Mixing (MX) Oceanographic Toolbox has errors !\n');
else
    fprintf(1,'Well done! The mx_check_fuctions confirms that the \n');
    fprintf(1,'Mixing (MX) Oceanographic Toolbox is installed correctly.\n');
    fprintf(1,' \n');
    fprintf(1,'You will find output figures saved in the ''figure'' \n');
    fprintf(1,'folder in the MX library.\n');
    fprintf(1,'\n');
    clear mx_cf mx_cv float_data mixing_data fig parameters run directory mx_parameters
end
