function [] = mx_derive_N2(dzN2)

% mx_derive_N2                             Derive the buoyancy frequency N2
%==========================================================================
%
% USAGE:
%  [] = mx_derive_N2(dzN2)
%
% DESCRIPTION:
%   Calculates the buoyancy frequency squared (N^2)(i.e. the Brunt-Vaisala 
%   frequency squared) at the mid pressure from the equation,
% 
%            2      2     d(rho_local)
%          N   =  g   x  --------------
%                            dP
%
% INPUT:
%  dz       = differential length (1 value)                          [dbar]
%
% OUTPUT:                     
%  N2       =  Brunt-Vaisala Frequency squared from Polzin code   [ 1/s^2 ]
%
% AUTHOR: 
% Amelie MEYER Based on Kurt Polzin original nsq_mod.m code
%
% VERSION NUMBER: 1.0 (19th June, 2014)
%
%==========================================================================
display('Derive the buoyancy frequency (N2)...');
warning('off','MATLAB:interp1:NaNinY')

load initial_data.mat

eval(['float' int2str(flt) '(1,1).N2=NaN;']);    	% Creates a new empty variable 
eval(['[c profiles]=size(float' int2str(flt) ');']);% Looks how many profiles there are for each float
for i=1:profiles;                                   % For each profile
    s=eval(['float' int2str(flt) '(i).SA']);      	% defines all variables for the nsq_modbs function
    t=eval(['float' int2str(flt) '(i).CT']);
    p=eval(['float' int2str(flt) '(i).Pctd']);
    sea_pressure=p-10.1325;
    lat=eval(['float' int2str(flt) '(i).lat']);
    % Derive N2 with nsq_modbs.m
    [nn,temp]=nsq_modbs(s,t,p,dzN2,lat);
    eval(['float',int2str(flt),'(i).N2=[nn];'])   	       
end

save('initial_data.mat','-regexp','^float','^flt');