function [] = mx_derive_abs_T_S

% mx_derive_abs_T_S   Derive absolute salinity and conservative temperature
%==========================================================================
%
% USAGE:
%  [] = mx_derive_abs_T_S
%
% DESCRIPTION:
%  Calculates Absolute Salinity from Practical Salinity.  Since SP is 
%   non-negative by definition, this function changes any negative input 
%   values of SP to be zero. Calculates Conservative Temperature of 
%   seawater from in-situ temperature.
%
% INPUT:
%   initial_data.mat 
%
% OUTPUT:
%  initial_data.mat	with:                      
%  SA               =  Absolute Salinity                           [ g/kg ]
%  CT               =  Conservative Temperature (ITS-90)          [ deg C ]
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (18th June, 2014)
%
% REFERENCES:
% McDougall, T.J. and P.M. Barker, 2011: Getting started with TEOS-10 and 
% the Gibbs Seawater (GSW) Oceanographic Toolbox, 28pp., SCOR/IAPSO WG127, 
% ISBN 978-0-646-55621-5. 
%
%==========================================================================
display('Derive Absolute Salinity and Conservative Temperature...');

load initial_data.mat

eval(['float' int2str(flt) '(1,1).SA=NaN;']);               % Creates a new empty variable 
eval(['float' int2str(flt) '(1,1).CT=NaN;']);               % Creates a new empty variable 
eval(['[c profiles]=size(float' int2str(flt) ');']);        % Looks how many profiles there are for each float
for i=1:profiles;                                           % For each profile
    P=eval(['float' int2str(flt) '(i).Pctd'])';             % Define all variables 
    S=eval(['float' int2str(flt) '(i).S'])';
    T=eval(['float' int2str(flt) '(i).T'])';
    lon=eval(['float' int2str(flt) '(i).lon'])';
    lat=eval(['float' int2str(flt) '(i).lat'])';
    % Derive absolute salinity SA
    SA=gsw_SA_from_SP(S,P,lon,lat);
    % Derive conseravtive temperature
    CT=gsw_CT_from_t(SA,T,P);
    % Add new variables to dataset   
    eval(['float',int2str(flt),'(i).SA=[SA''];'])
    eval(['float',int2str(flt),'(i).CT=[CT''];'])
    clear P S T lon lat SA CT
end

save('initial_data.mat','-regexp','^float','^flt');