function [] = mx_derive_fallrate

% mx_derive_fallrate            Derives the fallrate of the EM-APEX floats
%==========================================================================
%
% DESCRIPTION:
%  Calculates the fall rate of the EmApex and adds it as a variable to 
% initial_data_I. Uses the original pressure grid and the fact that 
% measurements are made every 25s to derive fall rate in m/s.
%
% INPUT:
%   initial_data.mat
%
% OUTPUT:
%	initial_data.mat
%
% AUTHOR: 
%  Amelie Meyer
%
% VERSION NUMBER: 1.1 (17th June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
display('Derive float fallrate...');

set(0,'RecursionLimit',600)

load initial_data.mat
t=25;   % time in second between each measurements...

eval(['Flt' int2str(int32(flt)) '(1,1).fallrate=NaN;']);  	% Creates a new empty variable fallrate in structure f3761...

eval(['[c profiles]=size(Flt' int2str(int32(flt)) ');']);  	% Looks how many profiles there are
 for i=1:profiles;                                          % For each profile
    l=eval(['length(Flt' int2str(int32(flt)) '(i).Pef);']);	% l is the number of bin depth in that profile
    distance=NaN(l,1);
    % FOR MOST BIN DEPTH
    for ii=2:l;
        distance(ii,1)=eval(['Flt' int2str(int32(flt)) '(i).Pef(ii)-Flt' int2str(int32(flt)) '(i).Pef(ii-1);']);
    end; clear ii
    % Calculate fallrate:
    fallrate=distance./t;           
    % Copy fallrate into structure
    eval(['Flt',int2str(int32(flt)),'(i).fallrate(1,1:l)=NaN;'])	 % Fills the empty variable with NaNs
    eval(['Flt',int2str(int32(flt)),'(i).fallrate(1,2:l)=fallrate(2:l);'])
    % FOR 1ST BIN DEPTH: copies the next value
    i_min=min(find(isnan(fallrate)==0));
    eval(['Flt',int2str(int32(flt)),'(i).fallrate(1,i_min-1)=fallrate(i_min);'])
    clear fallrate
 end

save('initial_data.mat','-regexp','^Flt','^flt');