function [] = mx_derive_mixed_layer_depth(drho)

% mx_derive_mixed_layer_depth                  Derive the mixed layer depth
%==========================================================================
%
% USAGE:
%  [] = mx_derive_mixed_layer_depth(drho)
%
% DESCRIPTION:
%   Derives mixed layer depth and adds variable MLD [db]. MLD is the depth 
% at which the potential density changes by a given threshold value drho = 
% 0.03km/m^3 relative to the one at a reference depth refdep=10m and 
% adding an extra 10m to be conservative.
%
% INPUT:
%  drho       = dendity change threshold                         	[-]
%
% OUTPUT:                     
%  MLD        =  Mixed layer depth                                  [ m ]
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (19th June, 2014)
%
% REFERENCES:
% deBoyer Montegut et al., 2004 JGR-Oceans vol 109,doi:10.1029/2004JC002378
%
%==========================================================================
display('Derive the mixed layer depth (MLD)...');
warning('off','MATLAB:interp1:NaNinY')
load initial_data.mat

% Constants
dT=0.2;
refdep=10;                                            	% Minimum depth for MLD

eval(['float' int2str(flt) '(1,1).MLD=NaN;']);    	% Creates a new empty variable 
eval(['[c profiles]=size(float' int2str(flt) ');']);% Looks how many profiles there are for each float
for i=1:profiles;                                 	% For each profile
    P=eval(['float' int2str(flt) '(i).Pctd'])';    	% defines all variables for the mixedlayerdepth function
    T=eval(['float' int2str(flt) '(i).CT'])';
    sigma_0=eval(['float' int2str(flt) '(i).sigma_0+1000'])';
    % Derive MLD
    [I_10]=max(find(P<=refdep));                    % Index value of closest data point to refdep (10m) 
    if P(1,1)>=refdep;                            	% Test to check that first value of press is within refdep
    else
        if ~isempty(I_10)                       	% If (I_10) is a value...
            ref_ptemp=T(I_10);                    	% Temperatue at refdep (10dbar)
            ref_pdens=sigma_0(I_10);               	% Potential density at refdep
            dT_profile=abs(T-ref_ptemp)-dT;         % Profile of anomaly potential temp minus dT
            ttt=find(dT_profile>0,1);              	% Finds index of first big spike in potential T
            drho_profile=abs(sigma_0-ref_pdens)-drho;% Profile of anomaly potential density minus dT
            if isempty(ttt)
                MLD=NaN;
            else
                MLD=P(max(find(drho_profile<0)));
            end
        end
    end
    eval(['float',int2str(flt),'(i).MLD=MLD+10;'])   	       
end

save('initial_data.mat','-regexp','^float','^flt');