function [mixing_data_gridded] = mx_derive_mixing(dz,fftpt,lzmin_fixed,lzmax_fixed,mx_parameters,run)

% mx_derive_mixing                                        Derive the mixing
%==========================================================================
%
% USAGE:
%  [] = mx_derive_mixing(dz,fftpt,lzmin_fixed,lzmax_fixed,mx_parameters,run)
%
% DESCRIPTION:

%         
% INPUT:
% 	dz      	= pressure grid interval for main gridding [m]
%	fftpt    	= Number of points for the fast fourier transform eg 128
%  	lzmin_fixed	= mini wavelength integration for shear/strain spectra	[m]
%  	lzmax_fixed	= maxi wavelength integration for shear/strain spectra 	[m]
%
% OUTPUT:                     
%   mixing_data_gridded.mat
%
% AUTHOR: 
%   Amelie MEYER
%
% VERSION NUMBER: 1.0 (25th June, 2014)
%
%==========================================================================
display('Derive mixing...');

%% SET PARAMETERS
% Load the parameters
eval(['load ' mx_parameters '.mat']);
% Difference in pressure between 2 adjacent bins:
dzfd=dz;       
% VERTICAL RESOLUTION
% vertical resoultion of CTD/strain profile:
dzg=dz;
% fftpt: set to 128 but could be 32,64,128... or any power of 2
fftpt;                           
% A function of how many points you want in each spectral calculation 
%(fftpt=vertical_bin_size/dzg)
vertical_bin_size=dzg*fftpt;
% The size of the overlap of vertical bins you are calculating spectra for 
% where 1/2 is equivalent to 50% overlapping bins.
dp_overlap=vertical_bin_size/2;
% (SW /2) vertical resolution of output (epsilon,kappa etc).The size of 
% this relative to dp_overlap will determine how much overlap/vertical 
% averaging goes into the estimate.Here set to segments that are 1/2 
%overlapping.
dp_resolution=dp_overlap/8;     

%% Estimate dissipation using shear parameterization
% Computes the dissipation rate (epsilon) and diapycnal 
% turbulent eddy diffusivity (kappa) using Henyey, Wright and Flatte 
% model fine scale parameterization of turbulent dissipation using shear 
% information only. This is computed in depth bins starting at the surface
% then down.  Implication:
% the bottom-most depth bin i snot full depth and the spectral 
% estimate in the bottom-most depth bin is maybe compromised.
mx_derive_mixing_shear

%% Estimate dissipation using strain parameterization
% Computes the dissipation rate (epsilon) and diapycnal 
% turbulent eddy diffusivity (kappa) using Henyey, Wright and Flatte 
% model fine scale parameterization of turbulent dissipation using strain 
% information only. This is computed in depth bins starting at the surface
% then down.  Implication:
% the bottom-most depth bin i snot full depth and the spectral 
% estimate in the bottom-most depth bin is maybe compromised.
mx_derive_mixing_strain

%% Finescale shear strain parameterization of dissipation
% Combines estimates of dissipation from shear and dissipation from strain 
% by computing the correction factor dependent on the observed (as opposed 
% to assumed) shear to strain ratio. We use the "straight-up" shear to 
% strain ratio and assume that the shear variance integral and strain 
% variance integral have been calculated using the same wavelength range 
% of integration.
mx_derive_mixing_shearstrain
