function [] = mx_derive_potential_density_anomaly

% mx_derive_potential_density_anomaly      Derive potential density anomaly
%==========================================================================
%
% USAGE:
%  [] = mx_derive_potential_density_anomaly
%
% DESCRIPTION:
%  Calculates potential density from Absolute Salinity and Conservative 
%   Temperature, using the computationally-efficient 48-term expression for
%   density in terms of SA, CT and p (McDougall et al., 2011).
%
% INPUT:
%  SA  =  Absolute Salinity                                        [ g/kg ]
%  CT  =  Conservative Temperature (ITS-90)                       [ deg C ]
%  p   =  sea pressure                                             [ dbar ]
%
% OUTPUT:                     
%  sigma_0  =  potential density anomaly referenced to sea level [ kg/m^3 ]
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (19th June, 2014)
%
% REFERENCES:
% McDougall, T.J. and P.M. Barker, 2011: Getting started with TEOS-10 and 
% the Gibbs Seawater (GSW) Oceanographic Toolbox, 28pp., SCOR/IAPSO WG127, 
% ISBN 978-0-646-55621-5. 
%
%==========================================================================
display('Derive potential density anomaly referred to the surface...');

load initial_data.mat

eval(['float' int2str(flt) '(1,1).sigma_0=NaN;']);          % Creates a new empty variable 
eval(['[c profiles]=size(float' int2str(flt) ');']);        % Looks how many profiles there are for each float
for i=1:profiles;                                           % For each profile
    SA=eval(['float' int2str(flt) '(i).SA'])';              % Define all variables 
    CT=eval(['float' int2str(flt) '(i).CT'])';
    % Derive potential density anomaly
    sigma_0=gsw_rho(SA,CT,0)-1000; % where 0 is the reference pressure point (sea level)
    % Add new variables to dataset   
    eval(['float',int2str(flt),'(i).sigma_0=[sigma_0''];'])
    clear SA CT
end
    
    save('initial_data.mat','-regexp','^float','^flt');