function [] = mx_derive_shear(dz,dzs)

% mx_derive_shear                                          Derive the shear
%==========================================================================
%
% USAGE:
%  [] = mx_derive_shear(dz,dzs)
%
% DESCRIPTION:
%   Derives shear where shear= complex(du,dv)/dp that is shear = dU/dP. 
%         
% INPUT:
%   dz          = vertical resolution of dataset [m]
%   dzs         = vertical scale over which shear is derived; 
%                 dzs must be a multiple of dz (3).
%
% OUTPUT:                     
%   shear     
%
% AUTHOR: 
%   Amelie MEYER
%
% VERSION NUMBER: 1.0 (24th June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
display('Derive the shear...');

load mixing_data.mat

d=dzs/dz; % equivalent of dzs in indexes
profiles=length(mixing_data.fltid);

for i=1:profiles;                                      
    % l is the number of bin depth in the profile:
    l=length(mixing_data.Pef);
    du=NaN(l,1);
    dv=NaN(l,1);
    dp=NaN(l,1);
    shear=NaN(l,1);

    % For most bin depth
    for ii=round(d/2)+1:l-round(d/2);
        du(ii,1)=mixing_data.U(ii+round(d/2),i)-mixing_data.U(ii-round(d/2),i);
        dv(ii,1)=mixing_data.V(ii+round(d/2),i)-mixing_data.V(ii-round(d/2),i);
        dp(ii,1)=mixing_data.Pef(ii+round(d/2),i)-mixing_data.Pef(ii-round(d/2),i);
    end;
    if isnan(du)==1; % if there is no vel data
        % Feels the empty variable with NaNs:
        mixing_data.shear(1:l,i)=NaN;     
    else
    % Calculate shear:
    shear=complex(du,dv)./dp;           
    % Copy shear into structure
    mixing_data.shear(1:l,i)=NaN;
    mixing_data.shear(:,i)=shear;
    end
end

save('mixing_data.mat','-regexp','^mixing_data','^flt');