function [] = mx_grid_all_initial_data

% mx_grid_all_initial_data                       Grid the initial data file
%==========================================================================
%
% USAGE:
%   [] = mx_grid_all_initial_data
%
% DESCRIPTION:
%  The initial variables are changed from a structure file into a matrix
% format ?initial_data_gridded.mat?.
%
% INPUT:
%   initial_data.mat
%
% OUTPUT:
%   initial_data_gridded.mat                     
%
% AUTHOR: 
%   Amelie MEYER
%
% VERSION NUMBER: 1.0 (23rd June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
display('Grid the initial data file into matrix format...');

load initial_data.mat

eval(['profilet=length(float' int2str(flt) ');']); % number of profiles for this float
eval(['profile_ctd=length(float' int2str(flt) '(1).Pctd);']); % length of each profile
eval(['profile_ef=length(float' int2str(flt) '(1).Pef);']); % length of each profile

%% Create empty matrices for all relevant variables
fltid=NaN(1,profilet);
profile_number=zeros(1,profilet);
lon=zeros(1,profilet);
lat=zeros(1,profilet);
surface_mlt=zeros(1,profilet);
MLD=NaN(1,profilet);
fallrate=zeros(profile_ef,profilet);
Pctd=NaN(profile_ctd,profilet);
SA=NaN(profile_ctd,profilet);
CT=NaN(profile_ctd,profilet);
sigma_0=NaN(profile_ctd,profilet);
N2=NaN(profile_ctd,profilet);
Pef=NaN(profile_ef,profilet);
U=NaN(profile_ef,profilet);
V=NaN(profile_ef,profilet);
speed=NaN(profile_ef,profilet);


%% Fill up the empty matrix with data using a loop through all flt all profiles;
for ii=1:profilet                       	% for each profile
    fltid(1,ii)=eval(['str2num(float' int2str(flt) '(ii).fltid);']);
    profile_number(1,ii)=eval(['float' int2str(flt) '(ii).profile_number;']);
    lon(1,ii)=eval(['float' int2str(flt) '(ii).lon;']);
    lat(1,ii)=eval(['float' int2str(flt) '(ii).lat;']);
    surface_mlt(1,ii)=eval(['float' int2str(flt) '(ii).surface_mlt;']);
    MLD(1,ii)=eval(['float' int2str(flt) '(ii).MLD;']);
    eval(['fallrate(:,ii)=float' int2str(flt) '(ii).fallrate;']);
    eval(['Pctd(:,ii)=float' int2str(flt) '(ii).Pctd;']);
    eval(['SA(:,ii)=float' int2str(flt) '(ii).SA;']);
    eval(['CT(:,ii)=float' int2str(flt) '(ii).CT;']);
    eval(['sigma_0(:,ii)=float' int2str(flt) '(ii).sigma_0;']);
    eval(['N2(:,ii)=float' int2str(flt) '(ii).N2;']);
    eval(['Pef(:,ii)=float' int2str(flt) '(ii).Pef;']);
    eval(['U(:,ii)=float' int2str(flt) '(ii).U;']);
    eval(['V(:,ii)=float' int2str(flt) '(ii).V;']);
    eval(['speed(:,ii)=float' int2str(flt) '(ii).speed;']);
end


%% NEW STRUCTURE
% Single values
initial_data_gridded.fltid=fltid;
initial_data_gridded.profile_number=profile_number;
initial_data_gridded.lon=lon;
initial_data_gridded.lat=lat;
initial_data_gridded.surface_mlt=surface_mlt;
initial_data_gridded.MLD=MLD;
% Many profiles
initial_data_gridded.fallrate=fallrate;
initial_data_gridded.Pctd=Pctd;
initial_data_gridded.SA=SA;
initial_data_gridded.CT=CT;
initial_data_gridded.sigma_0=sigma_0;
initial_data_gridded.N2=N2;
initial_data_gridded.Pef=Pef;
initial_data_gridded.U=U;
initial_data_gridded.V=V;
initial_data_gridded.speed=speed;

%% Save structure
clear fltid
save('initial_data_gridded.mat','-regexp','^initial_data_gridded','^flt');