function []=mx_grid_initialdata(U,V)

% mx_grid_initialdata                           Grid the initial data file
%==========================================================================
%
% USAGE:
%   [] = mx_grid_initialdata(U,V)
%
% DESCRIPTION:
%  Both the CTD data (temperature and salinity) and the EM data (velocity
% and fall rate) are gridded on a regular pressure grid. This grid is 
% preset to vertical intervals of 2.2 dbar for the CTD data and
% 3 dbar for the EM data. These values can be changed manually in the code.
% The gridded data is saved in the same structure ?initial data.mat?.
%
% INPUT:
%   initial_data.mat
%   U                   = U vel sensor eg '1' or '2'
%	V                	= V vel sensor eg '1' or '2'
%
% OUTPUT:
%   initial_data.mat                    
%
% AUTHOR: 
%   Amelie MEYER
%
% VERSION NUMBER: 1.0 (18th June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
display('Grid the initial data file...');

load initial_data.mat
warning('off','MATLAB:interp1:NaNinY');

eval(['[c profiles]=size(Flt' int2str(flt) ');']);% Looks how many profiles there are
% Copy data from initial_data_II.mat:             
for i=1:profiles;
    % Grab single variables
    eval(['float' int2str(flt) '(i).float_wmoid=Flt' int2str(flt) '(i).float_wmoid;']);
    eval(['float' int2str(flt) '(i).fltid=Flt' int2str(flt) '(i).fltid;']);        
    eval(['float' int2str(flt) '(i).profile_number=Flt' int2str(flt) '(i).profile_number;']);
    eval(['float' int2str(flt) '(i).surface_mlt=Flt' int2str(flt) '(i).surface_mlt;']);
    eval(['float' int2str(flt) '(i).lon=Flt' int2str(flt) '(i).lon;']);
    eval(['float' int2str(flt) '(i).lat=Flt' int2str(flt) '(i).lat;']);
    % Grab CTD variables and interp on a p gridd of 2.2 db
    ctdgrid=(1:2.2:1650)';                                  % Create new Pctd grid
    eval(['float' int2str(flt) '(i).Pctd=ctdgrid;']);       % add it to structure
    Pctd1=eval(['Flt' int2str(flt) '(i).Pctd'])';         	% Old Pct grid
    % Get rid of NaNs at bottom of variables:
    ind=min(find(isnan(Pctd1)))-1;	% finds the last good index of Pctd
    if isempty(ind)
        Pctd=Pctd1;
        ctd_mlt=eval(['Flt' int2str(flt) '(i).ctd_mlt;']);
        S=eval(['Flt' int2str(flt) '(i).S;']);
        T=eval(['Flt' int2str(flt) '(i).T;']);          
    else
        Pctd=Pctd1(1:ind);
        ctd_mlt=eval(['Flt' int2str(flt) '(i).ctd_mlt(1:ind);']);
        S=eval(['Flt' int2str(flt) '(i).S(1:ind);']);
        T=eval(['Flt' int2str(flt) '(i).T(1:ind);']);
    end
    eval(['float' int2str(flt) '(i).S=interp1(Pctd,S,ctdgrid);']);
    eval(['float' int2str(flt) '(i).T=interp1(Pctd,T,ctdgrid);']);
    eval(['float' int2str(flt) '(i).ctd_mlt=interp1(Pctd,ctd_mlt,ctdgrid);']);
    % Grab EM variables
    emgrid=(1:3:1650)';                                     % Create new Pctd grid
    eval(['float' int2str(flt) '(i).Pef=emgrid;']);         % add it to structure
    Pef=eval(['Flt' int2str(flt) '(i).Pef'])';          	% Old Pct grid
    ef_mlt=eval(['Flt' int2str(flt) '(i).ef_mlt']);  
    fallrate=eval(['Flt' int2str(flt) '(i).fallrate']);  
    u=eval(['Flt' int2str(flt) '(i).U' U '']);  
    v=eval(['Flt' int2str(flt) '(i).V' V '']);  
    eval(['float' int2str(flt) '(i).ef_mlt=interp1(Pef,ef_mlt,emgrid);']);
    eval(['float' int2str(flt) '(i).fallrate=interp1(Pef,fallrate,emgrid);']);
    eval(['float' int2str(flt) '(i).U=interp1(Pef,u,emgrid);']);
    eval(['float' int2str(flt) '(i).V=interp1(Pef,v,emgrid);']);
    clear Pef ef_mlt fallrate u v emgrid
end

save('initial_data.mat','-regexp','^float','^flt');