function [] = mx_grid_mixingdata(dz)

% mx_grid_mixingdata                              Grid the mixing data file
%==========================================================================
%
% USAGE:
%   [] = mx_grid_mixingdata(dz)
%
% DESCRIPTION:
%   Gridds both EM and CTD data from mixing_data.mat on same pressure grid.
%
% INPUT:
%   initial_data.mat
%   dz              = vertical resolution of dataset [m]
%
% OUTPUT:
%   mixing_data_gridded.mat                      
%
% AUTHOR: 
%   Amelie MEYER
%
% VERSION NUMBER: 1.0 (25th June, 2014)
%==========================================================================
display('Grid the mixing data onto one pressure grid...');

warning('off','MATLAB:interp1:NaNinY');

load mixing_data.mat
profiles=length(mixing_data.fltid);

%% Copy single variables in new structure
mixing_data_gridded.fltid=mixing_data.fltid;
mixing_data_gridded.profile_number=mixing_data.profile_number;
mixing_data_gridded.lon=mixing_data.lon;
mixing_data_gridded.lat=mixing_data.lat;
mixing_data_gridded.surface_mlt=mixing_data.surface_mlt;
mixing_data_gridded.MLD=mixing_data.MLD;

%% Grab CTD & EM variables and interp on a P gridd 
% Create new 3db pressure grid
P=(1:dz:1650)';
% For each profile
for i=1:profiles;                        	
    mixing_data_gridded.P(:,i)=P;
    mixing_data_gridded.SA(:,i)=interp1(mixing_data.Pctd(:,i),mixing_data.SA(:,i),P);
    mixing_data_gridded.CT(:,i)=interp1(mixing_data.Pctd(:,i),mixing_data.CT(:,i),P);
    mixing_data_gridded.sigma_0(:,i)=interp1(mixing_data.Pctd(:,i),mixing_data.sigma_0(:,i),P);
    mixing_data_gridded.N2(:,i)=interp1(mixing_data.Pctd(:,i),mixing_data.N2(:,i),P);
    mixing_data_gridded.N2_ref(:,i)=interp1(mixing_data.Pctd(:,i),mixing_data.N2_ref(:,i),P);
    mixing_data_gridded.N2_100m(:,i)=interp1(mixing_data.Pctd(:,i),mixing_data.N2_100m(:,i),P);
    mixing_data_gridded.strain(:,i)=interp1(mixing_data.Pctd(:,i),mixing_data.strain(:,i),P);
    mixing_data_gridded.fallrate(:,i)=interp1(mixing_data.Pef(:,i),mixing_data.fallrate(:,i),P);
    mixing_data_gridded.U(:,i)=interp1(mixing_data.Pef(:,i),mixing_data.U(:,i),P);
    mixing_data_gridded.V(:,i)=interp1(mixing_data.Pef(:,i),mixing_data.V(:,i),P);
    mixing_data_gridded.speed(:,i)=interp1(mixing_data.Pef(:,i),mixing_data.speed(:,i),P);
    mixing_data_gridded.shear(:,i)=interp1(mixing_data.Pef(:,i),mixing_data.shear(:,i),P);
end

save('mixing_data_gridded.mat','-regexp','^mixing_data_gridded','^flt');