function [] = mx_plot_N2(fig,directory)

% mx_plot_N2                                        Plot buoyancy frequency
%==========================================================================
%
% USAGE:
%  [] = mx_plot_N2(fig,directory)
%
% DESCRIPTION:
%  Plot all the buoyancy frequency profiles
%
% INPUT:
%  fig             = either 'on' or 'off' to utrn fig display on and off
%  directory       = path of directory where figure is saved 
%
% OUTPUT:
%  Figure:  /N2.eps                     
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (23rd June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
disp('Plot the buoyancy frequency (N2)...')

load initial_data_gridded.mat
load colormapbluegreen

%% Plot of temperature along profile numbers
nb_profiles=length(initial_data_gridded.fltid);
mini=min(min(initial_data_gridded.N2));
maxi=max(max(initial_data_gridded.N2));

h2=figure(2);
clf
set(2,'Position',[30 50 476 245]); % Where [horiz ver width height] of the figure width=1000 for first plot
eval(['set(2,''visible'',''' fig ''');'])                   
imagesc(1:nb_profiles,initial_data_gridded.Pctd(:,1),initial_data_gridded.N2);
hold on
axis ij
set(gca,'Position',[0.088 0.13 0.87 0.77])    % position of plot in figure
colormap(jet);
h=colorbar;	
set(get(h,'ylabel'),'string','N^2 [rad s^{-1}]^2 [g/kg]','fontsize',10);
caxis([0 maxi/10])
xlim([0 length(initial_data_gridded.profile_number)])
ylim([0 1600]);
xlabel('Cumulative profile number','FontSize',10);
ylabel('Pressure [dbar]','FontSize',10)

% Density contour
sigma_0=initial_data_gridded.sigma_0;
sigma_02=initial_data_gridded.sigma_0;
sigma_02(:,616:end)=NaN;
[C,h]=contour(1:length(initial_data_gridded.profile_number),initial_data_gridded.Pctd(:,1),sigma_0,[27:0.1:29],'color',[0.6 0.6 0.6],'linewidth',1);

title(['Float ' int2str(flt) ''])

% Saving figure options
set(gcf,'PaperPositionMode','auto')
set(gcf,'renderer','painters')
signature('')
print(h2,'-depsc2',['' directory '/figures/N2.eps']);