function [] = mx_plot_Rw(fig,directory,run)

% mx_plot_Rw                               Plot the shear/strain ratio (Rw)
%==========================================================================
%
% USAGE:
%  [] = mx_plot_Rw(fig,directory,run)
%
% DESCRIPTION:
%  Plot all the shear-to-strain variance ratio profiles.
%
% INPUT:
%  fig             = either 'on' or 'off' to utrn fig display on and off
%  directory       = path of directory where figure is saved 
%
% OUTPUT:
%  Figure:  /Rw.eps                     
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (26rd June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
disp('Plot the shear/strain ratio (Rw)...')

eval(['load mixing_data_gridded_' run '.mat']);

%% Plot
nb_profiles=length(mixing_data_gridded.fltid);
Rw=mixing_data_gridded.Rw;
mini=min(min(mixing_data_gridded.Rw));
maxi=max(max(mixing_data_gridded.Rw));

h2=figure(3);
clf
set(3,'Position',[30 50 476 245]); % Where [horiz ver width height] of the figure width=1000 for first plot
eval(['set(3,''visible'',''' fig ''');'])                   
imagesc(1:nb_profiles,mixing_data_gridded.P(:,1),Rw);
hold on
axis ij
set(gca,'Position',[0.088 0.13 0.87 0.77])    % position of plot in figure
colormap(flipud(fliplr(hot)));
h=colorbar;	
set(get(h,'ylabel'),'string','R_\omega','fontsize',10);
caxis([mini maxi])
xlim([0 length(mixing_data_gridded.profile_number)])
ylim([0 1600]);
xlabel('Cumulative profile number','FontSize',10);
ylabel('Pressure [dbar]','FontSize',10)

%% Density contour
sigma_0=mixing_data_gridded.sigma_0;
[C,h]=contour(1:length(mixing_data_gridded.profile_number),mixing_data_gridded.P(:,1),sigma_0,[27:0.1:29],'color',[0.6 0.6 0.6],'linewidth',1);

title(['Float ' int2str(flt) ''])

%% Saving figure options
set(gcf,'PaperPositionMode','auto')
set(gcf,'renderer','painters')
signature('Initial analysis','')
print(h2,'-depsc2',['' directory '/figures/Rw.eps']);