function []=f_plot_T_all(fltlist,run,fig)
%==========================================================================
% []=f_plot_T_all(fltlist,run,fig)
%
% DESCRIPTION: plot the temperature data for all floats in two figures.
% 
% ~/MATLAB/figures_matlab/T_S/temperature_x.png
% ~/MATLAB/figures_matlab/T_S/temperature_mean_x.png
%
% INPUT:     	fltlist         = vector of float numbers eg:"[3761 3952]"
%               run             = index of run eg 'a'
%               fig             = fig='off'-> figs are not displayed ('on')
%
% OUTPUT:    	Two figures
%
% Data input:  	~/MATLAB/analysis_initial/all_initial_data_x.mat
%               ~/MATLAB/analysis_initial/initial_data_diagnostic_x.mat
%              	~/MATLAB/routines/code_AMeyer/float_dynamic_color.mat
%               colormapbicolor.mat
%                                 
% AUTHOR:  Amelie Meyer Dec 2011
%==========================================================================
disp('f_plot_T_all')
eval(['load ~/MATLAB/analysis_initial/all_initial_data_' run '.mat']);
eval(['load ~/MATLAB/analysis_initial/initial_data_diagnostic_' run '.mat']);
load float_dynamic_color
load colormapbicolor

%% Plot of mean temperature profiles
h1=figure(8);
clf
set(8,'Position',[30 50 850 400]);      % Where [horiz ver width height] of the figure width=1000 for first plot
eval(['set(8,''visible'',''' fig ''');'])                   % when fig='off', doesnt display figure

% Plot of overall mean
subplot(1,2,1)
plot(average.Ttheta_profile,all_initial_data.Pctd(:,1),'color',[0 0 0],'linewidth',2)
ylabel('Depth [m]','FontSize',10)
xlabel('Potential temperature [^oC]','FontSize',10)
axis ij
set(gca,'XGrid','on','XMinorTick','on')
set(gca,'YGrid','on')
ylim([0 1600]);
xlim([2 14]);
title('Overall mean')

% Plot of each float mean
subplot(1,2,2)
for i=1:length(fltlist)                     % for each float
    flt=fltlist(1,i);
    T_mean=eval(['F' int2str(flt) '.Ttheta_mean_profile']);
    plot(T_mean,all_initial_data.Pctd(:,1),'color',float_dynamic_color(i,:),'marker','none','linewidth',1.5,'linestyle','-')
    hold on
end
axis ij
set(gca,'XGrid','on','XMinorTick','on')
xlabel('Potential temperature [^oC]','FontSize',10)
set(gca,'YGrid','on')
ylim([0 1600]);
xlim([2 14]);
title('Float''s mean')

%% Plot of temperature along profile numbers
T=all_initial_data.T;
S=all_initial_data.S;
P=all_initial_data.Pctd;
Ttheta=sw_ptmp(S,T,P,0);
mini=min(min(Ttheta));
maxi=max(max(Ttheta));

h2=figure(9);
clf
set(9,'Position',[30 50 476 245]); % Where [horiz ver width height] of the figure width=1000 for first plot
eval(['set(9,''visible'',''' fig ''');'])                   % when fig='off', doesnt display figure
imagesc(1:914,all_initial_data.Pctd(:,1),Ttheta);
hold on
axis ij
set(gca,'Position',[0.088 0.13 0.87 0.77])    % position of plot in figure
colormap(colormapbicolor);
h=colorbar;%('location','southoutside');       % Where [horiz ver width height]
set(get(h,'ylabel'),'string','Potential temperature [^oC]','fontsize',10);
caxis([mini maxi])
xlim([0 length(all_initial_data.PID)])
ylim([0 1600]);
xlabel('Cumulative profile number','FontSize',10);
ylabel('Depth [m]','FontSize',10)

% Temperature contour
%[C,h]=contour(1:length(all_initial_data.PID),all_initial_data.Pctd(:,1),Ttheta,[2 2.01],'color',[0 0 1],'linewidth',1);

% Density contour
sigmatheta=all_initial_data.sigmaTheta;
%sigmatheta(:,1:615)=NaN; % delete part of data set so only certain part of contours appear
sigmatheta2=all_initial_data.sigmaTheta;
sigmatheta2(:,616:end)=NaN;
[C,h]=contour(1:length(all_initial_data.PID),all_initial_data.Pctd(:,1),sigmatheta,[27.1 27.5],'color',[0 0 0],'linewidth',1);
%[C,h]=contour(1:length(all_initial_data.PID),all_initial_data.Pctd(:,1),sigmatheta2,[27.501 27.5],'color',[0 0 0],'linewidth',1);
annotation('textbox',[0.15 0.55 0.1 0.016],'String',{'27.5'},'color',[0 0 0],'FontSize',8,'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.365 0.41 0.1 0.016],'String',{'27.5'},'color',[0 0 0],'FontSize',8,'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.59 0.40 0.1 0.016],'String',{'27.5'},'color',[0 0 0],'FontSize',8,'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.76 0.21 0.1 0.016],'String',{'27.5'},'color',[0 0 0],'FontSize',8,'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.59 0.69 0.1 0.016],'String',{'27.1'},'color',[0 0 0],'FontSize',8,'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.76 0.62 0.1 0.016],'String',{'27.1'},'color',[0 0 0],'FontSize',8,'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.15 0.83 0.1 0.016],'String',{'27.1'},'color',[0 0 0],'FontSize',8,'FitBoxToText','off','EdgeColor','none');

% Water masses annotations
annotation('textbox',[0.74 0.80 0.1 0.016],'String',{'SAMW'},'color',[0 0 0],'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.74 0.44 0.1 0.016],'String',{'AAIW'},'color',[0 0 0],'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.13 0.30 0.1 0.016],'String',{'UCDW'},'color',[0 0 0],'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.35 0.30 0.1 0.016],'String',{'UCDW'},'color',[0 0 0],'FitBoxToText','off','EdgeColor','none');
%annotation('textbox',[0.13 0.88 0.1 0.016],'String',{'SAMW'},'color',[0 0 0],'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.13 0.70 0.1 0.016],'String',{'AAIW'},'color',[0 0 0],'FitBoxToText','off','EdgeColor','none');

% Lines to separate floats
[x,y]=ds2nfu([211 211],[0 1600]);
annotation('line',x,y,'LineWidth',4,'Color',[0.99 0.99 0.99]);
annotation('line',x,y,'LineWidth',1,'LineStyle','--','Color',[0 0 0]);
[x,y]=ds2nfu([299 299],[0 1600]);
annotation('line',x,y,'LineWidth',4,'Color',[0.99 0.99 0.99]);
annotation('line',x,y,'LineWidth',1,'LineStyle','--','Color',[0 0 0]);
[x,y]=ds2nfu([430 430],[0 1600]);
annotation('line',x,y,'LineWidth',4,'Color',[0.99 0.99 0.99]);
annotation('line',x,y,'LineWidth',1,'LineStyle','--','Color',[0 0 0]);
[x,y]=ds2nfu([488 488],[0 1600]);
annotation('line',x,y,'LineWidth',4,'Color',[0.99 0.99 0.99]);
annotation('line',x,y,'LineWidth',1,'LineStyle','--','Color',[0 0 0]);
[x,y]=ds2nfu([672 672],[0 1600]);
annotation('line',x,y,'LineWidth',4,'Color',[0.99 0.99 0.99]);
annotation('line',x,y,'LineWidth',1,'LineStyle','--','Color',[0 0 0]);
[x,y]=ds2nfu([708 708],[0 1600]);
annotation('line',x,y,'LineWidth',4,'Color',[0.99 0.99 0.99]);
annotation('line',x,y,'LineWidth',1,'LineStyle','--','Color',[0 0 0]);
[x,y]=ds2nfu([773 773],[0 1600]);
annotation('line',x,y,'LineWidth',4,'Color',[0.99 0.99 0.99]);
annotation('line',x,y,'LineWidth',1,'LineStyle','--','Color',[0 0 0]);

% Subantarctic front annotations
[x,y]=ds2nfu([615 615],[0 1600]);
annotation('line',x,y,'LineWidth',2,'LineStyle','-','Color',[1 0 0]);
annotation('textbox',[0.53 0.55 0.1 0.016],'String',{'SAF/'},'color',[1 0 0],'FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.53 0.51 0.1 0.016],'String',{'STF'},'color',[1 0 0],'FitBoxToText','off','EdgeColor','none');

% Add float's numbers
annotation('textbox',[0.14 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.265 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.36 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.435 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.53 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.62 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.67 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.76 0.99 0.1 0.016],'String','Float','color','w','FitBoxToText','off','EdgeColor','none');

annotation('textbox',[0.14 0.95 0.1 0.016],'String',{'3760'},'color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.265 0.95 0.1 0.016],'String',{'3761'},'color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.36 0.95 0.1 0.016],'String',{'3952'},'color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.435 0.95 0.1 0.016],'String',{'3950'},'color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.53 0.95 0.1 0.016],'String',{'3762'},'color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.62 0.95 0.1 0.016],'String',{'3951'},'color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.67 0.95 0.1 0.016],'String',{'4051'},'color','w','FitBoxToText','off','EdgeColor','none');
annotation('textbox',[0.76 0.95 0.1 0.016],'String',{'3764'},'color','w','FitBoxToText','off','EdgeColor','none');

% Saving figure options
set(gcf,'PaperPositionMode','auto')
set(gcf,'renderer','painters')
%texte_bas('EM-APEX data','Initial analysis')
print(h1,'-depsc2',['~/MATLAB/figures_matlab/T_S_density_MLD_N2/temperature_mean_' run '.eps']);
print(h2,'-depsc2',['~/MATLAB/figures_matlab/T_S_density_MLD_N2/temperature_' run '.eps']);
%print(h1,'-dpng',['~/MATLAB/figures_matlab/T_S_density_MLD_N2/temperature_mean_' run '.png']);
%print(h2,'-dpng',['~/MATLAB/figures_matlab/T_S_density_MLD_N2/temperature_' run '.png']);
