function [] = mx_plot_dissipation_rate(fig,directory,run)

% mx_plot_dissipation_rate                        Plot the dissipation rate
%==========================================================================
%
% USAGE:
%  [] = mx_plot_dissipation_rate(fig,directory,run)
%
% DESCRIPTION:
%  Plot all the dissipation rate profiles.
%
% INPUT:
%  fig             = either 'on' or 'off' to utrn fig display on and off
%  directory       = path of directory where figure is saved 
%
% OUTPUT:
%  Figure:  /dissipation_rate.eps                     
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (26rd June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
disp('Plot the dissipation rate (epsilon)...')

eval(['load mixing_data_gridded_' run '.mat']);

%% Plot of dissipation along profile numbers
nb_profiles=length(mixing_data_gridded.fltid);
mini=min(min(mixing_data_gridded.epsilon));
maxi=max(max(mixing_data_gridded.epsilon));
epsilon=mixing_data_gridded.epsilon;
epsilon(find(epsilon==0))=NaN;

h2=figure(3);
clf
set(3,'Position',[30 50 476 245]); % Where [horiz ver width height] of the figure width=1000 for first plot
eval(['set(3,''visible'',''' fig ''');'])                   
imagesc(1:nb_profiles,mixing_data_gridded.P(:,1),log10(epsilon));
hold on
axis ij
set(gca,'Position',[0.088 0.13 0.87 0.77])    % position of plot in figure
colormap(rot90(hot,2));
h=colorbar;	
set(get(h,'ylabel'),'string','log_{10}(\epsilon) [m^{2}s^{-3}]','fontsize',10);
caxis([log10(mini) log10(maxi)])
xlim([0 length(mixing_data_gridded.profile_number)])
ylim([0 1600]);
xlabel('Cumulative profile number','FontSize',10);
ylabel('Pressure [dbar]','FontSize',10)

%% Density contour
sigma_0=mixing_data_gridded.sigma_0;
[C,h]=contour(1:length(mixing_data_gridded.profile_number),mixing_data_gridded.P(:,1),sigma_0,[27:0.1:29],'color',[0.6 0.6 0.6],'linewidth',1);

title(['Float ' int2str(flt) ''])

%% Saving figure options
set(gcf,'PaperPositionMode','auto')
set(gcf,'renderer','painters')
signature('Initial analysis','')
print(h2,'-depsc2',['' directory '/figures/dissipation_rate.eps']);