function [] = mx_plot_mixed_layer_depth(fig,directory)

% mx_plot_mixed_layer_depth                      Plot the mixed layer depth
%==========================================================================
%
% USAGE:
%  [] = mx_plot_mixed_layer_depth(fig,directory)
%
% DESCRIPTION:
%  Plot all the mixed layer depth over the potential density profiles.
%
% INPUT:
%  fig             = either 'on' or 'off' to utrn fig display on and off
%  directory       = path of directory where figure is saved 
%
% OUTPUT:
%  Figure:  /mixed_layer_depth.eps                     
%
% AUTHOR: 
%  Amelie MEYER
%
% VERSION NUMBER: 1.0 (23rd June, 2014)
%
% RERENCE:  A. Meyer, B.M. Sloyan, K.L. Polzin, H.E. Phillips, and N.L. 
%           Bindoff. Mixing variability in the Southern Ocean. Journal of 
%           Physical Oceanography, 45,966-987, 2015.
%==========================================================================
disp('Plot the mixed layer depth (MLD)...')

load initial_data_gridded.mat
load colormapbluegreen

%% Plot
% Find index of 500 dbar
depth_ind=find(round(initial_data_gridded.Pctd(:,2))==500);
sigma_0=initial_data_gridded.sigma_0(1:depth_ind,:);
nb_profiles=length(initial_data_gridded.fltid);
mini=min(min(sigma_0));
maxi=max(max(sigma_0));

h2=figure(2);
clf
set(2,'Position',[30 50 476 245]); % Where [horiz ver width height] of the figure width=1000 for first plot
eval(['set(2,''visible'',''' fig ''');'])                   
imagesc(1:nb_profiles,initial_data_gridded.Pctd(:,1),initial_data_gridded.sigma_0);
hold on
axis ij
set(gca,'Position',[0.088 0.13 0.87 0.77])    % position of plot in figure
colormap(flipud(fliplr(hot)));
h=colorbar;	
set(get(h,'ylabel'),'string','\sigma_0 [kg m^{-3}]','fontsize',10);
caxis([mini maxi])
xlim([0 length(initial_data_gridded.profile_number)])
ylim([0 500]);
xlabel('Cumulative profile number','FontSize',10);
ylabel('Pressure [dbar]','FontSize',10)

% contour plot of the mixed layer depth
plot(initial_data_gridded.MLD,'color','k','linewidth',1)

title(['Float ' int2str(flt) ''])

% Saving figure options
set(gcf,'PaperPositionMode','auto')
set(gcf,'renderer','painters')
signature('')
print(h2,'-depsc2',['' directory '/figures/mixed_layer_depth.eps']);